require 'flexmock/rspec'
require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

PREFIX = "image_prefix"
OS_NAME = "os_name"
OS_VERSION = "os_version"
OS_ARCH = "os_arch"
OS_MODIFER = "os_modifier"
STORAGE_TYPE = "storage_type"
RELEASE_LEVEL = "Beta"
RIGHT_IMAGE_VERSION = "1.20"
SUFFIX = "suffix"


describe RightImage::Util, ".create_mci_name" do
  before(:each) do

    @name = RightImage::Util.create_mci_name(PREFIX,
          OS_NAME,
          OS_VERSION,
          OS_ARCH ,
          OS_MODIFER,
          "1.20",
          STORAGE_TYPE,
          RELEASE_LEVEL, SUFFIX)
  end

  it "should not have any blank fields" do
    @name.include?("__").should == false
  end

  it "should display two digit version number" do
    (@name =~ /_v[0-9]\.[0-9][0-9]/).should_not == nil
  end

  it "should display prefix" do
    @name.include?(PREFIX).should == true
  end

  it "should display OS_NAME" do
    @name.include?(OS_NAME).should == true
  end

  it "should display OS_VERSION" do
    @name.include?(OS_VERSION).should == true
  end

  it "should display OS_ARCH" do
    @name.include?(OS_ARCH).should == true
  end

  it "should display OS_MODIFER" do
    @name.include?(OS_MODIFER).should == true
  end

  it "should display RIGHT_IMAGE_VERSION" do
    @name.include?(RIGHT_IMAGE_VERSION.to_s).should == true
  end

  it "should display STORAGE_TYPE" do
    @name.include?(STORAGE_TYPE).should == true
  end

  it "should display RELEASE_LEVEL" do
    @name.include?(RELEASE_LEVEL).should == true
  end

  it "should display SUFFIX" do
    @name.include?(SUFFIX.capitalize).should == true
  end
end

describe RightImage::Util, ".create_mci_name S3" do
  before(:each) do
    @name = RightImage::Util.create_mci_name(PREFIX,
          OS_NAME,
          OS_VERSION,
          OS_ARCH ,
          OS_MODIFER,
          1.20,
          "S3",
          RELEASE_LEVEL, SUFFIX)
  end

  it "should not have any blank fields" do
    @name.include?("__").should == false
  end

  it "should not display S3" do
    @name.include?("S3").should_not == true
  end
end


describe RightImage::Util, ".create_mci_name GA" do

  before(:each) do
    @name = RightImage::Util.create_mci_name(PREFIX,
          OS_NAME,
          OS_VERSION,
          OS_ARCH ,
          OS_MODIFER,
          1.20,
          STORAGE_TYPE,
          "GA", SUFFIX)
  end

  it "should not have any blank fields" do
    @name.include?("__").should == false
  end

  it "should not display GA" do
    @name.include?("GA").should_not == true
  end
end

describe RightImage::Util, "rightimage_version" do

  it "should display two digit version number" do
    @version = RightImage::Util.rightimage_version(4.3)
    (@version =~ /^[0-9]\.[0-9]$/).should_not == nil
  end

  it "should display three digit version number" do
    @version = RightImage::Util.rightimage_version(4.3, 2)
    (@version =~ /^[0-9]\.[0-9]\.[0-9]$/).should_not == nil
  end

  it "should display four digit version number" do
    @version = RightImage::Util.rightimage_version(4.3, 2, 1)
    (@version =~ /^[0-9]\.[0-9]\.[0-9]\.[0-9]$/).should_not == nil
  end

  it "should hide fourth digit if zero" do
    @version = RightImage::Util.rightimage_version(4.3, 2, 0)
    (@version =~ /^[0-9]\.[0-9]\.[0-9]$/).should_not == nil
  end

  it "should fail if version is N.N.N format" do
    lambda {
      @version = RightImage::Util.rightimage_version("4.3.5")
    }.should raise_error(Exception)
  end

  it "should fail if version is N format" do
    lambda {
      @version = RightImage::Util.rightimage_version(4)
    }.should raise_error(Exception)
  end

end

describe RightImage::Util, ".create_image_name GA" do

  before(:each) do
    @name = RightImage::Util.create_image_name("RightImage", \
          "osname", \
          "9.10", \
          "x64", \
          nil, \
          1.20, \
          3, \
          0,
          "S3",
          "GA")
  end

  it "should not have any blank fields" do
    @name.include?("__").should == false
  end

  it "should display a three digit version number without zero build digit" do
    (@name =~ /_v[0-9]\.[0-9]\.[0-9]/).should_not == nil
  end

  it "should display version number without 4th build digit" do
    (@name =~ /_v[0-9]\.[0-9]\.[0-9]\.0/).should == nil
  end

  it "should not display GA" do
    @name.include?("GA").should == false
  end

  it "should not display S3" do
    @name.include?("S3").should == false
  end

  it "should display RightImage" do
    @name.include?("RightImage").should == true
  end

  it "should include trailing zero on version number" do
    @name.include?("9.10").should == true
  end
end

describe RightImage::Util, ".create_image_name Beta EBS" do
  before(:each) do
    @name = RightImage::Util.create_image_name("RightImage", \
          "osname", \
          "99.99", \
          "x64", \
          nil, \
          1.2, \
          3, \
          4,
          "EBS",
          "Beta")
  end

  it "should not have any blank fields" do
    @name.include?("__").should == false
  end

  it "should display a four digit version number" do
    (@name =~ /_v[0-9]\.[0-9]\.[0-9]\.[0-9]/).should_not == nil
  end

  it "should display Beta" do
    @name.include?("Beta").should == true
  end

  it "should display EBS" do
    @name.include?("EBS").should == true
  end
end

describe RightImage::Util, ".create_image_name Alpha S3 Dev" do
  before(:each) do
    @name = RightImage::Util.create_image_name("RightImage", \
          "osname", \
          "99.99", \
          "x64", \
          nil, \
          1.2, \
          3, \
          4,
          "EBS",
          "Alpha",
          "dev0")
  end

  it "should not have any blank fields" do
    @name.include?("__").should == false
  end

  it "should display Alpha" do
    @name.include?("Alpha").should == true
  end

  it "should display capitalized dev0" do
    @name.include?("Dev0").should == true
  end
end
